// this function verifies disk space in kilobytes
function verifyDiskSpace(dirPath, spaceRequired)
{
	var spaceAvailable;

	// Get the available disk space on the given path
	spaceAvailable = fileGetDiskSpaceAvailable(dirPath);

	// Convert the available disk space into kilobytes
	spaceAvailable = parseInt(spaceAvailable / 1024);

	// do the verification
	if(spaceAvailable < spaceRequired)
	{
		logComment("Insufficient disk space: " + dirPath);
		logComment("  required : " + spaceRequired + " K");
		logComment("  available: " + spaceAvailable + " K");
		return(false);
	}

	return(true);
}

// OS type detection
// which platform?
function getPlatform()
{
	var platformStr;
	var platformNode;

	if('platform' in Install)
	{
		platformStr = new String(Install.platform);

		if (!platformStr.search(/^Macintosh/))
			platformNode = 'mac';
		else if (!platformStr.search(/^Win/))
			platformNode = 'win';
		else
			platformNode = 'unix';
	}
	else
	{
		var fOSMac  = getFolder("Mac System");
		var fOSWin  = getFolder("Win System");

		logComment("fOSMac: "  + fOSMac);
		logComment("fOSWin: "  + fOSWin);

		if(fOSMac != null)
			platformNode = 'mac';
		else if(fOSWin != null)
			platformNode = 'win';
		else
			platformNode = 'unix';
	}

	return platformNode;
}


// main
var srDest = 800;
var err;
var fProgram;
var platformNode;

platformNode = getPlatform();
logComment("initInstall: platformNode=" + platformNode);
// end - OS type detection

// ----LOCALIZATION NOTE: translate only these ------
var prettyName = "Slovensky (SK)";
var langcode = "sk";
var regioncode = "SK";
var chromeNode = langcode + "-" + regioncode;
// --- END CHANGABLE STUFF ---
var regName      = "locales/mozilla/" + chromeNode;
var chromeName   = chromeNode + ".jar";
var regionFile   = regioncode + ".jar";
var platformName = langcode + "-" + platformNode + ".jar";
var localeName   = "locale/" + chromeNode + "/";
var regionName   = "locale/" + regioncode + "/";

err    = initInstall(prettyName, regName, "1.6.b");
logComment("initInstall: " + err);

fProgram = getFolder("Program");
logComment("fProgram: " + fProgram);

if(verifyDiskSpace(fProgram, srDest))
{
	var chromeType = LOCALE;
	var tellRestart = 0;
	if (platformNode == 'unix') {
		// DELAYED_CHROME is still needed on many unix systems for bug 109044; this needs a Mozilla restart!
		logComment("detected a unix system: using DELAYED_CHROME for registerChrome because of bug 109044");
		chromeType |= DELAYED_CHROME;
		tellRestart = 1;
	}

	err = addDirectory("", "bin", fProgram, "");
	logComment("addDirectory() returned: " + err);

	if (err != SUCCESS)
	{
		var bla;
		logComment("addDirectory() to " + fProgram + "failed!");

		// couldn't install globally, try installing to the profile

		bla = confirm ("In\u0161tal\u00E1cia pre v\u0161etk\u00FDch u\u017E\u00EDvate\u013Eov zlyhala. " +
			"Chcete tento jazykov\u00FD bal\u00EDk nain\u0161talova\u0165 iba pre seba, do va\u0161ho profilu? " +
		"(Pozor, pri takejto in\u0161tal\u00E1cii sa m\u00F4\u017Ee slovensk\u00FD preklad \u010Diasto\u010Dne " +
		"objavi\u0165 u\u017E po prvom re\u0161tarte. A\u017E po zvolen\u00ED jazyka 'Slovensky' a druhom " +
		"re\u0161tarte bude Mozilla \u00FAplne po slovensky.\n\n" +
		"System-wide installation failed. " +
		"Do you want to install this langpack only for you, into your profile? " +
		"(Warning, with this installation may Mozilla get partially slovak " +
		"already after first reboot. Only after choosing language 'Slovensky' " +
		"and second reboot Mozilla gets fully slovak.");

		if (bla == 0)
		{
			cancelInstall(err);
			logComment("User refused to install into profile");
		}


		// does not work with DELAYED_CHROME !!!
		resetError();
		chromeType = LOCALE | PROFILE_CHROME;  // DELAYED_CHROME here would cause error 
		fProgram = getFolder("Profile");
		logComment("try installing to the user profile:" + fProgram);
		err = addDirectory("","bin/chrome",fProgram,"chrome");
	}


	setPackageFolder(fProgram);

	if ((err == 0) || (err == 999)) 
	{
		var tellReboot = 0;
		if (err == 999) 
		{
			tellReboot = 1;
			resetError();
		}

		var cf = getFolder(fProgram, "chrome/"+chromeName);
		var pf = getFolder(fProgram, "chrome/"+platformName);
		var rf = getFolder(fProgram, "chrome/"+regionFile);

		registerChrome(chromeType, cf, localeName + "communicator/");
		registerChrome(chromeType, cf, localeName + "content-packs/");
		registerChrome(chromeType, cf, localeName + "cookie/");
		registerChrome(chromeType, cf, localeName + "editor/");
		registerChrome(chromeType, cf, localeName + "global/");
		registerChrome(chromeType, cf, localeName + "help/");
		registerChrome(chromeType, cf, localeName + "messenger/");
		registerChrome(chromeType, cf, localeName + "messenger-smime/");
		registerChrome(chromeType, cf, localeName + "mozldap/");
		registerChrome(chromeType, cf, localeName + "necko/");
		registerChrome(chromeType, cf, localeName + "navigator/");
		registerChrome(chromeType, cf, localeName + "p3p/");
		registerChrome(chromeType, cf, localeName + "pipnss/");
		registerChrome(chromeType, cf, localeName + "pippki/");
		registerChrome(chromeType, cf, localeName + "wallet/");

		registerChrome(chromeType, pf, localeName + "communicator-platform/");
		registerChrome(chromeType, pf, localeName + "global-platform/");
		registerChrome(chromeType, pf, localeName + "navigator-platform/");
		if (platformNode == "win") 
		{
			registerChrome(chromeType, pf, localeName + "messenger-mapi/");
		}

//		registerChrome(chromeType, rf, regionName + "global-region/");
//		registerChrome(chromeType, rf, regionName + "communicator-region/");
//		registerChrome(chromeType, rf, regionName + "editor-region/");
//		registerChrome(chromeType, rf, regionName + "messenger-region/");
//		registerChrome(chromeType, rf, regionName + "navigator-region/");


		err = performInstall();
		logComment("performInstall() returned: " + err);
		if (err == 999)
		{
			tellReboot = 1;
			resetError();
		}
		if (err == 0) 
		{
			if (tellReboot == 1) 
			{
				alert("In\u0161tal\u00E1cia prebehla \u00FAspe\u0161ne. Pros\u00EDm, RE\u0160TARTUJTE PO\u010C\u00CDTA\u010C. " + 
				"Po re\u0161tarte spustite Mozillu znovu. Cez  Edit - Preferences - " +
				"Appearance - Languages/Content  " +
				"si vyberte jazyk 'Slovensky' a kliknite na OK. " +
				"Potom Mozillu re\u0161tartujte, aby sa zmena jazyka uplatnila.\n\n" +	
				"Installation finished. Please REBOOT YOUR SYSTEM. " +
				"After restart, run Mozilla again. Via  Edit - Preferences - " + 
				"Appearance - Languages/Content  " +
				"select the language 'Slovensky' and click OK. " +
				"Then restart Mozilla to apply the change of the language.");

				logComment("REBOOT_NEEDED (999): warning user that he needs to reboot his system.");
			}
			else 
			{
				if (tellRestart == 1) 
				{   
					alert("In\u0161tal\u00E1cia prebehla \u00FAspe\u0161ne. Pros\u00EDm, re\u0161tartujte Mozillu. " + 
					"Potom cez  Edit - Preferences - " +
					"Appearance - Languages/Content  " +
					"si vyberte jazyk 'Slovensky' a kliknite na OK. " +
					"Potom Mozillu znovu re\u0161tartujte, aby sa zmena jazyka uplatnila.\n\n" +	
					"Installation finished. Please restart Mozilla. " +
					"Then, via  Edit - Preferences - " + 
					"Appearance - Languages/Content  " +
					"select the language 'Slovensky' and click OK. " +
					"Then restart Mozilla again, to apply the change of the language.");

					logComment("we were using DELAYED_CHROME: warning user that he needs to restart Mozilla.");
				}
				else  
				{
					alert("In\u0161tal\u00E1cia prebehla \u00FAspe\u0161ne. " + 
					"Cez  Edit - Preferences - " +
					"Appearance - Languages/Content  " +
					"si vyberte jazyk 'Slovensky' a kliknite na OK. " +
					"Potom Mozillu re\u0161tartujte, aby sa zmena jazyka uplatnila.\n\n" +	
					"Installation finished. " +
					"Via  Edit - Preferences - " + 
					"Appearance - Languages/Content  " +
					"select the language 'Slovensky' and click OK. " +
					"Then restart Mozilla to apply the change of the language.");
				}
			}
		}
		else 
		{
			alert("In\u0161t\u00E1lacia zlyhala. K\u00F3d chyby bol " + err + ".\n\n" + 
			"Installation failed. Error code was " + err + ".");
		}
	}
	else {
		cancelInstall(err);
		logComment("cancelInstall due to error: " + err);
		if (err == -202) 
		{
			alert("In\u0161tal\u00E1cia bola zru\u0161en\u00E1 s chybou " + err +
			". Asi nem\u00E1te pr\u00E1vo zapisova\u0165 do adres\u00E1ra  'chrome' Mozilly. " + 
			"Pros\u00EDm in\u0161talujte jazykov\u00FD bal\u00EDk ako root / systemov\u00FD administr\u00E1tor.\n\n" + 
			"Installation canceled with error " + err +
			". It seems you have no write permission to the Mozilla 'chrome' directory. " + 
			"Please install the langpack as root / system administrator.");
		}
		else 
		{
			alert("In\u0161tal\u00E1cia bola zru\u0161en\u00E1. K\u00F3d chyby bol " + err + ".\n\n" + 
			"Installation canceled. Error code was " + err + ".");
		}
	}
}
else
	cancelInstall(INSUFFICIENT_DISK_SPACE);


// end main
